@@ -5,5 +5,5 @@ panelhist <- function(x, ...)
     h <- hist(x, plot = FALSE)
     breaks <- h$breaks; nB <- length(breaks)
     y <- h$counts; y <- y/max(y)
-    rect(breaks[-nB], 0, breaks[-1], y, col="blue", ...)
+    rect(breaks[-nB], 0, breaks[-1], y, col="blue", border="blue", ...)
 }
